==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/CREDITCARDUSERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CREDITCARDUSERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CREDITCARDUSERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREDITCARDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CREDITCARDUSERID_Type", propOrder = {
    "creditcardid",
    "userid"
})
public class CREDITCARDUSERID_Type {

    @XmlElement(name = "CREDITCARDID", required = true)
    protected CREDITCARDID_Type creditcardid;
    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;

    /**
     * Gets the value of the creditcardid property.
     * 
     * @return
     *     possible object is
     *     {@link CREDITCARDID_Type }
     *     
     */
    public CREDITCARDID_Type getCREDITCARDID() {
        return creditcardid;
    }

    /**
     * Sets the value of the creditcardid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CREDITCARDID_Type }
     *     
     */
    public void setCREDITCARDID(CREDITCARDID_Type value) {
        this.creditcardid = value;
    }

    /**
     * Gets the value of the userid property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Sets the value of the userid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

}

==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/CREDITCARDUSERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CREDITCARDUSERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CREDITCARDUSERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREDITCARDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CREDITCARDUSERID_Type", propOrder = {
    "creditcardid",
    "userid"
})
public class CREDITCARDUSERID_Type {

    @XmlElement(name = "CREDITCARDID", required = true)
    protected CREDITCARDID_Type creditcardid;
    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;

    /**
     * Obtient la valeur de la propriété creditcardid.
     * 
     * @return
     *     possible object is
     *     {@link CREDITCARDID_Type }
     *     
     */
    public CREDITCARDID_Type getCREDITCARDID() {
        return creditcardid;
    }

    /**
     * Définit la valeur de la propriété creditcardid.
     * 
     * @param value
     *     allowed object is
     *     {@link CREDITCARDID_Type }
     *     
     */
    public void setCREDITCARDID(CREDITCARDID_Type value) {
        this.creditcardid = value;
    }

    /**
     * Obtient la valeur de la propriété userid.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Définit la valeur de la propriété userid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

}
